@@ -12,17 +12,17 @@ URL = "https://useast.ensembl.org/index.html"
 
 
 class EnsemblGetter(Getter):
-    """A getter for DrugBank."""
+    """A getter for Ensembl."""
 
     bioregistry_id = "ensembl"
     name = "Ensembl"
     homepage_fmt = "https://www.ensembl.org"
-    date_fmt = "%b %Y"
+    date_fmt = "%B %Y"
     version_type = VersionType.sequential
 
     def get(self):
         """Get the latest Ensembl version number."""
-        soup = get_soup(URL, verify=False)
+        soup = get_soup(URL)
         manifest = soup.find(**{"class": "box-header"}).text
         version, date = manifest.rstrip(")").split("(", 1)
         return dict(version=version.split()[-1], date=date)
