@@ -3,7 +3,6 @@
 """A getter for Rhea."""
 
 import requests
-import requests_ftp
 
 from bioversions.utils import Getter, VersionType
 
@@ -11,9 +10,7 @@ __all__ = [
     "RheaGetter",
 ]
 
-requests_ftp.monkeypatch_session()
-
-VERSION_FILE = "ftp://ftp.expasy.org/databases/rhea/rhea-release.properties"
+VERSION_FILE = "https://ftp.expasy.org/databases/rhea/rhea-release.properties"
 
 
 class RheaGetter(Getter):
